contexttools.ClefMark
=====================

.. abjad-lineage:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark

.. autoclass:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.middle_c_position
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.clef_name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__repr__
   :noindex:
